@@ -1,11 +1,11 @@
 from fireo.fields.base_field import Field
 from fireo.fields.id_field import IDField
 from fireo.fields.boolean_field import BooleanField
-from fireo.fields.data_time import DateTime
-from fireo.fields.geo_point import GeoPoint
+from fireo.fields.datetime_field import DateTime
+from fireo.fields.geo_point_field import GeoPoint
 from fireo.fields.list_field import ListField
 from fireo.fields.map_field import MapField
-from fireo.fields.nested_model import NestedModel
+from fireo.fields.nested_model_field import NestedModel
 from fireo.fields.number_field import NumberField
 from fireo.fields.reference_field import ReferenceField
 from fireo.fields.text_field import TextField
