@@ -39,4 +39,7 @@ def get_nested(dict, *args):
         element = args[0]
         if element:
             value = dict.get(element)
-            return value if len(args) == 1 else get_nested(value, *args[1:])
\ No newline at end of file
+            return value if len(args) == 1 else get_nested(value, *args[1:])
+
+def generateKeyFromId(model, id):
+    return model.collection_name + "/" + id
\ No newline at end of file
